==> jc-1.4.0.tar.gz: javax/swing/JToolBar__24AccessibleJToolBar.h <==
// public class javax.swing.JToolBar$AccessibleJToolBar

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class ccd521e115950694 javax_swing_JToolBar__24AccessibleJToolBar

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JToolBar__24AccessibleJToolBar_H_
#define _JC_javax_swing_JToolBar__24AccessibleJToolBar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_swing_JToolBar$object;

// Typedefs
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$refs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$refs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object	_jc_javax_swing_JToolBar__24AccessibleJToolBar$object;

typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct	_jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct;
typedef const struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods;
typedef const struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable;
typedef const struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype;

// Class fields structure
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$class_fields;

// Constructors
extern void _jc_javax_swing_JToolBar__24AccessibleJToolBar$method$_init$e628186abfa61473(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *, struct _jc_javax_swing_JToolBar$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JToolBar__24AccessibleJToolBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JToolBar__24AccessibleJToolBar$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToolBar__24AccessibleJToolBar$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JToolBar__24AccessibleJToolBar$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *);
};

// Vtable
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods	javax_swing_JToolBar__24AccessibleJToolBar;
};

// Vtype
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype {
	_jc_type			type;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs {
	struct _jc_javax_swing_JToolBar$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$refs {
    _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs	javax_swing_JToolBar__24AccessibleJToolBar;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs	javax_swing_JToolBar__24AccessibleJToolBar;
};

// Object instance structure
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object {
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype	*vtype;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype _jc_javax_swing_JToolBar__24AccessibleJToolBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToolBar__24AccessibleJToolBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToolBar__24AccessibleJToolBar$class_object;

#endif	/* _JC_javax_swing_JToolBar__24AccessibleJToolBar_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JToolBar__24AccessibleJToolBar.h <==
// public class javax.swing.JToolBar$AccessibleJToolBar

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 1ff60f65c3647f41 javax_swing_JToolBar__24AccessibleJToolBar

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JToolBar__24AccessibleJToolBar_H_
#define _JC_javax_swing_JToolBar__24AccessibleJToolBar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_swing_JToolBar$object;

// Typedefs
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$refs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$refs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs	_jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs;
typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object	_jc_javax_swing_JToolBar__24AccessibleJToolBar$object;

typedef struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct	_jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct;
typedef const struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods;
typedef const struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable;
typedef const struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype;

// Class fields structure
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JToolBar__24AccessibleJToolBar$fields_struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$class_fields;

// Constructors
extern void _jc_javax_swing_JToolBar__24AccessibleJToolBar$method$_init$e628186abfa61473(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *, struct _jc_javax_swing_JToolBar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JToolBar__24AccessibleJToolBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JToolBar__24AccessibleJToolBar$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToolBar__24AccessibleJToolBar$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JToolBar__24AccessibleJToolBar$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vmethods	javax_swing_JToolBar__24AccessibleJToolBar;
};

// Vtype
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype {
	_jc_type			type;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs {
	struct _jc_javax_swing_JToolBar$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$refs {
    _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_refs	javax_swing_JToolBar__24AccessibleJToolBar;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JToolBar__24AccessibleJToolBar$sub_nonrefs	javax_swing_JToolBar__24AccessibleJToolBar;
};

// Object instance structure
struct _jc_javax_swing_JToolBar__24AccessibleJToolBar$object {
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype	*vtype;
	_jc_javax_swing_JToolBar__24AccessibleJToolBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToolBar__24AccessibleJToolBar$vtype _jc_javax_swing_JToolBar__24AccessibleJToolBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToolBar__24AccessibleJToolBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToolBar__24AccessibleJToolBar$class_object;

#endif	/* _JC_javax_swing_JToolBar__24AccessibleJToolBar_H_ */
